/* 
 * File:     pwm.c 
 * Author:   Jun Okamoto Jr.
 * Date:     7/02/2016
 * Comments: Gera PWM para acionamento dos motores.
 *           Esta implementao  s para testes do hardware, as funes
 *           pwm_init e pwm_set devero ser implementadas na Atividade 6.
 * Revision history: 
 */

#ifndef PWM_C
#define PWM_C

#include <stdio.h>
#include "always.h"
#include "pwm.h"

#define PWM1 RC2  // somente para teste de hw
#define PWM2 RC1  // somente para teste de hw

///
/// Inicializa a funo de PWM com uma determinada frequencia
///
void pwm_init(){
  // Para os testes  usado o Timer 1 e as sadas dos sinais de PWM para 
  // os motores so configuradas diretamente nos pinos.
  // Dever ser re-implementada utilizando os PWM's com sadas como CCP1 e CCP2
  
  // Configurao do Timer 1
  TMR1ON = 1;   // habilita Timer 1
  TMR1CS = 0;   // usa clock interno FOSC/4
  T1OSCEN = 0;  // oscilador LP desligado
  T1CKPS0 = 0;  // prescaler 1:1
  T1CKPS1 = 0;  // prescaler 1:1
  TMR1GE = 0;   // Timer 1 est sempre contando
  TMR1 = 0xffff - 1000; // contagem
  
  // Sada dos sinais de PWM
  TRISC1 = 0; // RC1  sada para PWM2
  TRISC2 = 0; // RC2  sada para PWM1
  PWM1 = 0;   // sada do PWM1  zero inicialmente
  PWM2 = 0;   // sada do PWM2  zero inicialmente
  
  // Sada dos sinais de direo
  ANS4 = 0;   // RA5  digital
  TRISA5 = 0; // RA5  sada
  TRISA6 = 0; // RA6  sada
  DIR1 = 0;   // direo do motor 1 (RA5)
  DIR2 = 0;   // direo do motor 2 (RA6)
}

///
/// Define o duty cycle da saida PWM
/// @param channel - canal do PWM (1: motor 1; 2: motor 2)
/// @param duty_cycle - porcentagem do duty cycle x 10 (valor de 0 a 1000)
///
void pwm_set(int channel, int duty_cycle){
  // No implementado para os testes  
  // dever ser implementado pelos alunos na Atividade 6
}

///
/// Altera a direo de movimento
/// @param dir - cdigo de direo
///              0 - para frente (ou qualquer outro valor)
///              1 - para trs
///              2 - gira para a esquerda
///              3 - gira para a direira
///
void pwm_direction(int dir) {
  switch (dir) {
    case 1: // para trs
      DIR1 = 1;
      DIR2 = 1;
      break;
    case 2: // para a esquerda
      DIR1 = 1;
      DIR2 = 0;
      break;
    case 3: // para a direita
      DIR1 = 0;
      DIR2 = 1;
      break;
    default: // para frente
      DIR1 = 0;
      DIR2 = 0;
  } 
}

#endif
